# Project

This is my simple python project, which could do some simple stuff, like:
    - Logging
    - Managing files
    - Reading OS data
    - Sending data
    - Pinging IPs
    - Pinging ports
    - Creating zip files
    - Modifying registry entries
    - Calculating system resources
    - Overtaking the keyboard or mouse
    - Creating folders
    - Managing CTk windows
    - Checking for internet connection
    - Checking for open ports
    - Checking if running on a virtual machine
    - Generating passwords
    - Capturing images
    - Capturing screen
    - Getting WiFi passwords
    - Leaking system data
    - Sending emails
    - Creating shortcuts
    - Displaying desktop notifications
    - Playing music
    - Encrypting and decrypting data with AES256
    - Hashing files and strings
    - Converting time units
    - Formatting text
    - Stripping strings
    - Creating tables
    - Waiting for a specified time
    - Getting system information
    - Getting disk information
    - Getting battery status
    - Getting base path
    - Getting parent folder
    - Listing processes
    - Killing processes
    - Checking for WiFi connections

However, this project is very simple, but effective.


## Settings

You can manage some things in the settings file of the project,
which is directly in the parent folder of it.